@@ -1,25 +1,10 @@
 package Email::Sender::Transport::Sendmail;
+our $VERSION = '0.091660';
+
 use Moose;
-extends 'Email::Sender::Transport';
+with 'Email::Sender::Transport';
+# ABSTRACT: send mail via sendmail(1)
 
-our $VERSION = '0.004';
-
-=head1 NAME
-
-Email::Sender::Transport::Sendmail - send mail via sendmail(1)
-
-=head2 DESCRIPTION
-
-This transport sends mail by piping it to the F<sendmail> command.  If the
-location of the F<sendmail> command is not provided in the constructor (see
-below) then the library will look for an executable file called F<sendmail> in
-the path.
-
-To specify the location of sendmail:
-
-  my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
-
-=cut
 
 use File::Spec ();
 
@@ -39,6 +24,10 @@ has 'sendmail' => (
   },
 );
 
+sub BUILD {
+  $_[0]->sendmail; # force population -- rjbs, 2009-06-08
+}
+
 sub _find_sendmail {
   my ($self, $program_name) = @_;
   $program_name ||= 'sendmail';
@@ -85,3 +74,41 @@ sub send_email {
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Sender::Transport::Sendmail - send mail via sendmail(1)
+
+=head1 VERSION
+
+version 0.091660
+
+=head2 DESCRIPTION
+
+This transport sends mail by piping it to the F<sendmail> command.  If the
+location of the F<sendmail> command is not provided in the constructor (see
+below) then the library will look for an executable file called F<sendmail> in
+the path.
+
+To specify the location of sendmail:
+
+  my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut 
+
+
